pub struct MockDeviceInfo<T: TestLayerMock> {
pub mock_hooks: Mutex<MockDeviceHooks>,
/* private fields */
}Available on crate feature
_test only.Expand description
A mock struct that implements the DeviceInfo trait.
The T type parameter is a TestLayerMock type that provides the mock of
DeviceInfo::hooked_commands.
Fields
mock_hooks: Mutex<MockDeviceHooks>The mock of the DeviceHooks.
Implementations
Sourceimpl<T: TestLayerMock> MockDeviceInfo<T>
impl<T: TestLayerMock> MockDeviceInfo<T>
Sourcepub fn with_mock_drop(&self, f: impl FnOnce(&mut MockDrop))
pub fn with_mock_drop(&self, f: impl FnOnce(&mut MockDrop))
Mock the drop behavior.
The expectations can be set through the f argument. If this method is never called, the
struct will be dropped as if the drop is not mocked, i.e. won’t check how drop is called.