pub struct MockInstanceInfo<T: TestLayerMock> {
pub mock_hooks: Mutex<MockInstanceHooks>,
/* private fields */
}Available on crate feature
_test only.Expand description
A mock struct that implements the InstanceInfo trait.
The T type parameter is a TestLayerMock type that provides the mock of
InstanceInfo::hooked_commands.
Fields
mock_hooks: Mutex<MockInstanceHooks>The mock of the InstanceHooks.
Implementations
Sourceimpl<T: TestLayerMock> MockInstanceInfo<T>
impl<T: TestLayerMock> MockInstanceInfo<T>
Sourcepub fn with_mock_drop(&self, f: impl FnOnce(&mut MockDrop))
pub fn with_mock_drop(&self, f: impl FnOnce(&mut MockDrop))
Mock the drop behavior.
The expectations can be set through the f argument. If this method is never called, the
struct will be dropped as if the drop is not mocked, i.e. won’t check how drop is called.