pub struct TestGlobal<T: TestLayerTag = Tag<0>> { /* private fields */ }Available on crate feature
_test only.Expand description
The container of the static resources related to TestLayer<T>.
Use the TestGlobal::builder to construct one.
Implementations
Sourceimpl<T: TestLayerTag> TestGlobal<T>
impl<T: TestLayerTag> TestGlobal<T>
Sourcepub const fn builder() -> TestGlobalBuilder<T>
pub const fn builder() -> TestGlobalBuilder<T>
Create the builder for initialization.
Sourcepub fn create_context(&'static self) -> Box<dyn Any>
pub fn create_context(&'static self) -> Box<dyn Any>
Create a context for expectations for the static object.