#[repr(C)]pub struct VkLayerInstanceCreateInfo {
pub sType: StructureType,
pub pNext: *const c_void,
pub function: VkLayerFunction,
pub u: VkLayerInstanceCreateInfoUField,
}Available on crate feature
_test only.Expand description
Sub type of structure for instance and device loader ext of CreateInfo.
When sType is
VK_STRUCTURE_TYPE_LOADER_INSTANCE_CREATE_INFO
then VkLayerFunction indicates struct type pointed to by pNext.
Fields
sType: StructureTypeA VkStructureType value identifying this struct. Must be
VK_STRUCTURE_TYPE_LOADER_INSTANCE_CREATE_INFO.
pNext: *const c_voidEither NULL or a pointer to a structure extending this structure.
function: VkLayerFunctionA VkLayerFunction value identifying the payload in the u field.
u: VkLayerInstanceCreateInfoUFieldThe actual payload.